@@ -12,6 +12,9 @@
   Refactored April 30, 2012. -vladimir.v.diaz
 
 <Copyright>
+  2008-2011 The Tor Project, Inc
+  2012-2016 New York University and the TUF contributors
+  2016-2021 Securesystemslib contributors
   See LICENSE for licensing information.
 
 <Purpose>
@@ -63,24 +66,13 @@
   signable_object = make_signable(unsigned_object)
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import binascii
 import calendar
-import re
-import string
 import datetime
 import time
-import six
 
-import securesystemslib.schema as SCHEMA
-import securesystemslib.exceptions
+from securesystemslib import exceptions
+from securesystemslib import schema as SCHEMA
 
 # Note that in the schema definitions below, the 'SCHEMA.Object' types allow
 # additional keys which are not defined. Thus, any additions to them will be
@@ -411,7 +403,7 @@ KEYDICT_SCHEMA = SCHEMA.DictOf(
   key_schema = KEYID_SCHEMA,
   value_schema = KEY_SCHEMA)
 
-ANY_SIGNATURE_SCHEMA = securesystemslib.schema.OneOf([SIGNATURE_SCHEMA,
+ANY_SIGNATURE_SCHEMA = SCHEMA.OneOf([SIGNATURE_SCHEMA,
     GPG_SIGNATURE_SCHEMA])
 
 # List of ANY_SIGNATURE_SCHEMA.
@@ -477,7 +469,7 @@ def datetime_to_unix_timestamp(datetime_object):
   # Raise 'securesystemslib.exceptions.FormatError' if not.
   if not isinstance(datetime_object, datetime.datetime):
     message = repr(datetime_object) + ' is not a datetime.datetime() object.'
-    raise securesystemslib.exceptions.FormatError(message)
+    raise exceptions.FormatError(message)
 
   unix_timestamp = calendar.timegm(datetime_object.timetuple())
 
@@ -515,7 +507,7 @@ def unix_timestamp_to_datetime(unix_timestamp):
 
   # Is 'unix_timestamp' properly formatted?
   # Raise 'securesystemslib.exceptions.FormatError' if there is a mismatch.
-  securesystemslib.formats.UNIX_TIMESTAMP_SCHEMA.check_match(unix_timestamp)
+  UNIX_TIMESTAMP_SCHEMA.check_match(unix_timestamp)
 
   # Convert 'unix_timestamp' to a 'time.struct_time',  in UTC.  The Daylight
   # Savings Time (DST) flag is set to zero.  datetime.fromtimestamp() is not
@@ -555,7 +547,7 @@ def format_base64(data):
     return binascii.b2a_base64(data).decode('utf-8').rstrip('=\n ')
 
   except (TypeError, binascii.Error) as e:
-    raise securesystemslib.exceptions.FormatError('Invalid base64'
+    raise exceptions.FormatError('Invalid base64'
       ' encoding: ' + str(e))
 
 
@@ -582,9 +574,9 @@ def parse_base64(base64_string):
     'base64_string'.
   """
 
-  if not isinstance(base64_string, six.string_types):
+  if not isinstance(base64_string, str):
     message = 'Invalid argument: '+repr(base64_string)
-    raise securesystemslib.exceptions.FormatError(message)
+    raise exceptions.FormatError(message)
 
   extra = len(base64_string) % 4
   if extra:
@@ -595,7 +587,7 @@ def parse_base64(base64_string):
     return binascii.a2b_base64(base64_string.encode('utf-8'))
 
   except (TypeError, binascii.Error) as e:
-    raise securesystemslib.exceptions.FormatError('Invalid base64'
+    raise exceptions.FormatError('Invalid base64'
       ' encoding: ' + str(e))
 
 
@@ -620,7 +612,7 @@ def _canonical_string_encoder(string):
     A string with the canonical-encoded 'string' embedded.
   """
 
-  string = '"%s"' % re.sub(r'(["\\])', r'\\\1', string)
+  string = '"%s"' % string.replace('\\', '\\\\').replace('"', '\\"')
 
   return string
 
@@ -629,7 +621,7 @@ def _encode_canonical(object, output_function):
   # Helper for encode_canonical.  Older versions of json.encoder don't
   # even let us replace the separators.
 
-  if isinstance(object, six.string_types):
+  if isinstance(object, str):
     output_function(_canonical_string_encoder(object))
   elif object is True:
     output_function("true")
@@ -637,7 +629,7 @@ def _encode_canonical(object, output_function):
     output_function("false")
   elif object is None:
     output_function("null")
-  elif isinstance(object, six.integer_types):
+  elif isinstance(object, int):
     output_function(str(object))
   elif isinstance(object, (tuple, list)):
     output_function("[")
@@ -650,7 +642,7 @@ def _encode_canonical(object, output_function):
   elif isinstance(object, dict):
     output_function("{")
     if len(object):
-      items = sorted(six.iteritems(object))
+      items = sorted(object.items())
       for key, value in items[:-1]:
         output_function(_canonical_string_encoder(key))
         output_function(":")
@@ -662,7 +654,7 @@ def _encode_canonical(object, output_function):
       _encode_canonical(value, output_function)
     output_function("}")
   else:
-    raise securesystemslib.exceptions.FormatError('I cannot encode '+repr(object))
+    raise exceptions.FormatError('I cannot encode '+repr(object))
 
 
 def encode_canonical(object, output_function=None):
@@ -725,9 +717,9 @@ def encode_canonical(object, output_function=None):
   try:
     _encode_canonical(object, output_function)
 
-  except (TypeError, securesystemslib.exceptions.FormatError) as e:
+  except (TypeError, exceptions.FormatError) as e:
     message = 'Could not encode ' + repr(object) + ': ' + str(e)
-    raise securesystemslib.exceptions.FormatError(message)
+    raise exceptions.FormatError(message)
 
   # Return the encoded 'object' as a string.
   # Note: Implies 'output_function' is None,
